# URTutils
import os
_homedir = os.environ["HOME"]
def pad_date(l):
    y = l[0]
    m = l[1]
    d = l[2]
    while len(y)<4:
        y = "0" + y
    while len(m)<2:
        m = "0" + m
    while len(d)<2:
        d = "0" + d
    return [y, m, d]
def submit_to_user_file(day, rating):
    cur = get_user_file()
    if type(day)==type([]):
        day = list(map(str, day))
        day = pad_date(day)
        day = "".join(day)
    if not cur:
        create_user_file()
        cur = get_user_file()
    cur[day] = rating
    update_user_file(cur)

def get_user_file():
    try:
        f = open("{}/.urtoday".format(_homedir), "r")
    except FileNotFoundError:
        return False
    lines = f.readlines()
    cur = {}
    for line in lines:
        l2 = line.split()
        date = l2[0]
        rate = l2[1]
        cur[date] = int(rate)
    return cur

def create_user_file():
    f = open("{}/.urtoday".format(_homedir), "x")
    f.close()
    return True

def update_user_file(cur):
    f = open("{}/.urtoday".format(_homedir), "w")
    lines = []
    for ind in cur:
        date = ind
        rate = cur[ind]
        line = "{} {}\n".format(date, rate)
        lines += [line]
    f.writelines(lines)
    f.close()


def get_day_range_values(days):
    import time as _time
    import datetime as _datetime
    today = list(_time.localtime())[0:3]
    stoday = list(map(str, today))
    stoday = pad_date(stoday)
    dttoday = _datetime.date(*today)
    dtdelta = _datetime.timedelta(days=days)
    dtfirstday = dttoday - dtdelta
    firstdaystr = [str(dtfirstday.year), str(dtfirstday.month), str(dtfirstday.day)]
    firstdaystr = pad_date(firstdaystr)
    firstdaystr = "".join(firstdaystr)
    f = get_user_file()
    lk = list(f.keys())
    firstdayindex = lk.index(firstdaystr)
    newkeys = lk[firstdayindex:]
    retlist = []
    for key in newkeys:
        try:
            retlist += [f[key]]
        except:
            pass
    return retlist

def get_average(days):
    vals = get_day_range_values(days)
    s = sum(vals)
    count = len(vals)
    avg = s / count
    return avg

def get_min(days):
    vals = get_day_range_values(days)
    return min(vals)

def get_max(days):
    vals = get_day_range_values(days)
    return max(vals)

def get_median(days):
    vals = get_day_range_values(days)
    median = vals[int(len(vals)/2)] if len(vals)%2==1 else (vals[int(len(vals)/2)-1]+vals[int(len(vals)/2)])/2
    return median




import tkinter as tk
import tkinter.messagebox as tkmessagebox

def submit_today():
    global today, window
    import time as _time
    tday = list(_time.localtime())[0:3]
    rating = today.get()
    try:
        import urtutils as urtu
    except ImportError:
        import urtoday.urtutils as urtu
    urtu.submit_to_user_file(tday, rating)
    tkmessagebox.showinfo("Successful!", "Your today rating: {}".format(rating))
    window.quit()


window = tk.Tk()
window.title("URtoday")

text0 = tk.Label(window, text="How do you rate your today [1-100]?")
text0.pack()

today = tk.Scale(window, from_=1, to=100, orient=tk.HORIZONTAL)
today.set(64)
today.pack(anchor=tk.CENTER)

read_today = tk.Button(window, text="Submit", command=submit_today)
read_today.pack()
def run():
    window.mainloop()
    window.destroy()

if __name__=="__main__":
    run()



import tkinter as tk
import tkinter.messagebox as tkmessagebox

def get_overview():
    global window, days
    try:
        import urtutils as urtu
    except Exception as e:
        import urtoday.urtutils as urtu
    d = days.get()
    try:
        avg = urtu.get_average(d)
        Min = urtu.get_min(d)
        Max = urtu.get_max(d)
        med = urtu.get_median(d)
        tkmessagebox.showinfo("Overview", "Ratings overview for {} past days:\nAverage rating: {}\nMinimum rating: {}\nMaximum rating: {}\nMedian value: {}".format(d+1, avg,Min,Max,med))
        window.quit()
    except:
        tkmessagebox.showinfo("Overview, Error", "Data for the selected range is not available (Do you selected a day you haven't rated?)")

window = tk.Tk()
window.title("URtoday Overview")

text0 = tk.Label(window, text="How many days do you want to get overview?")
text0.pack()

days = tk.Scale(window, from_=1, to=730, orient=tk.HORIZONTAL)
days.set(30)
days.pack(anchor=tk.CENTER)

read_today = tk.Button(window, text="Get Overview", command=get_overview)
read_today.pack()

def run():
    window.mainloop()
    window.destroy()

if __name__=="__main__":
    run()



import setuptools
import urtoday as urt

with open("README.md") as f:
    long_desc = f.read()


setuptools.setup(
        name="urtoday",
        version=urt.version,
        description="URtoday",
        long_description=long_desc,
        long_description_content_type="text/markdown",
        url="https://github.com/poyynt/urtoday/",
        author="Parsa Torbati",
        author_email="parsa@programmer.net",
        packages=setuptools.find_packages(),
        python_requires=">=3.2",
        entry_points={
            "console_scripts": [
                "urtoday=urtoday.main:run",
                "urtoday-overview=urtoday.overview:run",
                ],
            },
        classifiers=[
            "Programming Language :: Python :: 3",
            "License :: OSI Approved :: Apple Public Source License",
            "Operating System :: OS Independent",
            "Development Status :: 5 - Production/Stable",
            "Natural Language :: English",
            "Topic :: Utilities",
            ],
        )
